import unittest
from pytest_opentmi.OpenTmiReport import OpenTmiReport


class MockPluginManager:
    def hasplugin(self, plugin):
        return False


class MockConfig:
    pluginmanager = MockPluginManager()

    def getoption(self, opt):
        if opt == 'opentmi':
            return 'https://localhost'
        if opt == 'opentmi_store_logs':
            return False
        raise AssertionError('invalid opt')


class TestPlugin(unittest.TestCase):

    def test_constructor(self):
        report = OpenTmiReport(config=MockConfig())
        self.assertIsInstance(report, OpenTmiReport)

    def test_get_test_key(self):
        report = OpenTmiReport(config=MockConfig())

        class Item:
            @property
            def location(self):
                return ['a', 2, 'b']
        key = report._get_test_key(Item())
        self.assertEqual(key, 'a_2_b')



# pylint: disable=missing-docstring

import unittest


class TestCli(unittest.TestCase):

    def test_dummy(self):
        """
        It's saturday evening and sauna is on, so have no time to implement tests for now.
        This is totally against my principals but sometimes "poikkeus vahvistaa säännön".
        Instead writing tests, I'll get one beer and go to sauna, sorry about buggy plugin.
        """
        pass



import pytest


def setup_function(function):
    pass


def teardown_function(function):
    pass


def setup_module(module):
    #assert 0, 'oh no, setup module fails'
    pass

def teardown_module(module):
    pass


@pytest.mark.slow
def test_first_test():
    print('testing')


def test_second_test(record_property):
    record_property("example_key", 1)


def test_third_test():
    pass


@pytest.mark.skip(reason="no way of currently testing this")
def test_skip_marker():
    pass


def test_skip():
    pytest.skip("unsupported configuration")


@pytest.mark.xfail(reason='expected to fail')
def test_xfail():
    raise AssertionError('oh no')
